aboutsummaryrefslogtreecommitdiffstats
path: root/lib/pama
diff options
context:
space:
mode:
authorKoni Marti <koni.marti@gmail.com>2024-01-31 17:23:00 +0100
committerRobin Jarry <robin@jarry.cc>2024-01-31 21:57:28 +0100
commit4cc2e6be3a010ecfba314909ce9b594f04e1be0e (patch)
treee22c025e90e79dbe21843bb5e5a2ccbfaab5ae31 /lib/pama
parent29ee43aceb7cdd5e28c71c133c9c97ec1f98f8a6 (diff)
downloadaerc-4cc2e6be3a010ecfba314909ce9b594f04e1be0e.tar.gz
commands: rename patch delete to patch unlink
Rename the command :patch delete to :patch unlink. This expresses the "link" between the project data within aerc and the underlying repository better. :patch unlink does not delete anything in the repository, it only removes the metadata about currently applied patch revisions/tags. Signed-off-by: Koni Marti <koni.marti@gmail.com> Acked-by: Robin Jarry <robin@jarry.cc>
Diffstat (limited to 'lib/pama')
-rw-r--r--lib/pama/unlink.go (renamed from lib/pama/delete.go)4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/pama/delete.go b/lib/pama/unlink.go
index 53dbeeb1..2def5403 100644
--- a/lib/pama/delete.go
+++ b/lib/pama/unlink.go
@@ -6,8 +6,8 @@ import (
"git.sr.ht/~rjarry/aerc/log"
)
-// Delete removes provided project
-func (m PatchManager) Delete(name string) error {
+// Unlink removes provided project
+func (m PatchManager) Unlink(name string) error {
store := m.store()
names, err := m.Names()
if err != nil {